# Table of Contents

- [authentication-to-sap-leanix-services](<./authentication-to-sap-leanix-services.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Authentication to SAP LeanIX Services](<./Authentication-to-SAP-LeanIX-Services.md>)
  - [Authentication Flow](<./Authentication-to-SAP-LeanIX-Services/Authentication-Flow.md>)
  - [Step 1: Get an API Token](<./Authentication-to-SAP-LeanIX-Services/Step-1-Get-an-API-Token.md>)
  - [Step 2: Get an Access Token](<./Authentication-to-SAP-LeanIX-Services/Step-2-Get-an-Access-Token.md>)
  - [Step 3: Make Authenticated Requests to Services](<./Authentication-to-SAP-LeanIX-Services/Step-3-Make-Authenticated-Requests-to-Services.md>)
  - [Was this page helpful?](<./Authentication-to-SAP-LeanIX-Services/Was-this-page-helpful.md>)
